@@ -11,13 +11,9 @@ class RedisQuerySet(django_models.query.QuerySet):
         concrete_model = self.model
         redis_root = get_redis_root()
         id = concrete_model.id
-        print('\nRedisQuerySet update:')
-        print('update', concrete_model, self)
-        django_ids_to_update = [django_instance.id for django_instance in self]
+        django_ids_to_update = [int(django_instance.id) for django_instance in self]
         data_to_update = redis_root.get(self.model, django_id__in=django_ids_to_update)
-        print(f'now data to update {self.model}:', len(data_to_update))
         redis_root.update(self.model, data_to_update, **kwargs)
-        print(f'now redis {self.model}:', redis_root.get(self.model))
         return self
 
     def create(self, **kwargs):
@@ -29,8 +25,10 @@ class RedisQuerySet(django_models.query.QuerySet):
         redis_root = get_redis_root()
         for field in create_result.__class__._meta.get_fields():
             try:
-                print(field)
-                existing_fields[field.name] = django_instance_field_to_redis_value(
+                field_name = field.name
+                if field_name in ['id', 'pk']:
+                    field_name = 'django_id'
+                existing_fields[field_name] = django_instance_field_to_redis_value(
                     redis_root,
                     create_result,
                     field,
@@ -44,9 +42,9 @@ class RedisQuerySet(django_models.query.QuerySet):
     def delete(self):
         concrete_model = self.model._meta.concrete_model
         delete_result = super().delete()
-        print('delete', concrete_model, concrete_model.id)
         redis_root = get_redis_root()
-        data_to_delete = redis_root.get(self.model, django_id=concrete_model.id)
+        django_instance_ids_to_delete = [int(django_instance.id) for django_instance in self]
+        data_to_delete = redis_root.get(self.model, django_id__in=django_instance_ids_to_delete)
         redis_root.delete(self.model, data_to_delete)
         return self
 
@@ -84,7 +82,6 @@ def django_instance_field_to_redis_value(
             django_foreign_key_instance = django_field_value
             if save_related_models:
                 if django_foreign_key_instance:
-                    print('creating new instance foreign', django_field, django_foreign_key_instance)
                     django_instance_model = django_foreign_key_instance.__class__
                     redis_foreign_key_instance = get_or_create_redis_instance_from_django_instance(
                         redis_root,
@@ -101,7 +98,6 @@ def django_instance_field_to_redis_value(
         if save_related_models:
             if len(django_many_to_many_instances):
                 django_instance_model = django_many_to_many_instances[0].__class__
-                print('creating new instance m2m', django_field, django_instance_model)
                 redis_value = [
                     get_or_create_redis_instance_from_django_instance(
                         redis_root,
@@ -190,7 +186,10 @@ class DjangoRedisModel(django_models.Model):
         redis_root = get_redis_root()
         for field in self.__class__._meta.get_fields():
             try:
-                existing_fields[field.name] = django_instance_field_to_redis_value(
+                field_name = field.name
+                if field_name in ['id', 'pk']:
+                    field_name = 'django_id'
+                existing_fields[field_name] = django_instance_field_to_redis_value(
                     redis_root,
                     self,
                     field,
@@ -202,11 +201,12 @@ class DjangoRedisModel(django_models.Model):
         return self
 
     def delete(self, *args, **kwargs):
-        django_id = self.id
+        django_id = int(self.id)
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
         if redis_instance_qs:
+            print(self.__class__)
             redis_root.delete(self.__class__, redis_instance_qs)
         return self
 
@@ -223,7 +223,10 @@ class DjangoRedisUserModel(AbstractUser):
         redis_root = get_redis_root()
         for field in self.__class__._meta.get_fields():
             try:
-                existing_fields[field.name] = django_instance_field_to_redis_value(
+                field_name = field.name
+                if field_name in ['id', 'pk']:
+                    field_name = 'django_id'
+                existing_fields[field_name] = django_instance_field_to_redis_value(
                     redis_root,
                     self,
                     field,
@@ -235,11 +238,12 @@ class DjangoRedisUserModel(AbstractUser):
         return self
 
     def delete(self, *args, **kwargs):
-        django_id = self.id
+        django_id = int(self.id)
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
         if redis_instance_qs:
+            print(self.__class__)
             redis_root.delete(self.__class__, redis_instance_qs)
         return self
 
